@@ -1,7 +1,7 @@
 package App::CalcAccumulatedDiscounts;
 
 our $DATE = '2015-12-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,13 @@ _
         },
     },
     examples => [
-        { argv => [] },
+        {
+            args => {},
+        },
+        {
+            summary => 'Modify years and discount rates to generate',
+            args => {years=>[5,10], discounts=>[1,2,2.5]},
+        },
     ],
     result_naked => 1,
 };
@@ -83,7 +89,7 @@ App::CalcAccumulatedDiscounts - Calculate multi-year discounts from a per-year d
 
 =head1 VERSION
 
-This document describes version 0.02 of App::CalcAccumulatedDiscounts (from Perl distribution App-CalcAccumulatedDiscounts), released on 2015-12-17.
+This document describes version 0.03 of App::CalcAccumulatedDiscounts (from Perl distribution App-CalcAccumulatedDiscounts), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
@@ -306,6 +312,24 @@ Result:
  ]
 
 
+ calc_accumulated_discounts( discounts => [1, 2, 2.5], years => [5, 10]);
+
+
+Result:
+
+ [
+   200,
+   "OK",
+   [
+     ["Disc p.a. \\ Year", "5y", "10y"],
+     ["1.00%", "4.9%", "9.6%"],
+     ["2.00%", "9.6%", "18.3%"],
+     ["2.50%", "11.9%", "22.4%"],
+   ],
+ ]
+Modify years and discount rates to generate.
+
+
 This routine generates a table of accumulated discounts over a period of several
 years, given the annual discount rates.
 
